==> zio-aws-elasticache_2.12-5.17.103.1-sources.jar: zio/aws/elasticache/model/DescribeEventsResponse.scala <==
package zio.aws.elasticache.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DescribeEventsResponse(
    marker: Option[String] = None,
    events: Option[Iterable[zio.aws.elasticache.model.Event]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticache.model.DescribeEventsResponse = {
    import DescribeEventsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticache.model.DescribeEventsResponse
      .builder()
      .optionallyWith(marker.map(value => value: java.lang.String))(_.marker)
      .optionallyWith(
        events.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.events)
      .build()
  }
  def asReadOnly: zio.aws.elasticache.model.DescribeEventsResponse.ReadOnly =
    zio.aws.elasticache.model.DescribeEventsResponse.wrap(buildAwsValue())
}
object DescribeEventsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticache.model.DescribeEventsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.elasticache.model.DescribeEventsResponse =
      zio.aws.elasticache.model.DescribeEventsResponse(
        marker.map(value => value),
        events.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def marker: Option[String]
    def events: Option[List[zio.aws.elasticache.model.Event.ReadOnly]]
    def getMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("marker", marker)
    def getEvents
        : ZIO[Any, AwsError, List[zio.aws.elasticache.model.Event.ReadOnly]] =
      AwsError.unwrapOptionField("events", events)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticache.model.DescribeEventsResponse
  ) extends zio.aws.elasticache.model.DescribeEventsResponse.ReadOnly {
    override val marker: Option[String] =
      scala.Option(impl.marker()).map(value => value: String)
    override val events
        : Option[List[zio.aws.elasticache.model.Event.ReadOnly]] = scala
      .Option(impl.events())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.elasticache.model.Event.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticache.model.DescribeEventsResponse
  ): zio.aws.elasticache.model.DescribeEventsResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-elasticache_2.12-5.20.7.3-sources.jar: zio/aws/elasticache/model/DescribeEventsResponse.scala <==
package zio.aws.elasticache.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DescribeEventsResponse(
    marker: Optional[String] = Optional.Absent,
    events: Optional[Iterable[zio.aws.elasticache.model.Event]] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticache.model.DescribeEventsResponse = {
    import DescribeEventsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticache.model.DescribeEventsResponse
      .builder()
      .optionallyWith(marker.map(value => value: java.lang.String))(_.marker)
      .optionallyWith(
        events.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.events)
      .build()
  }
  def asReadOnly: zio.aws.elasticache.model.DescribeEventsResponse.ReadOnly =
    zio.aws.elasticache.model.DescribeEventsResponse.wrap(buildAwsValue())
}
object DescribeEventsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticache.model.DescribeEventsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.elasticache.model.DescribeEventsResponse =
      zio.aws.elasticache.model.DescribeEventsResponse(
        marker.map(value => value),
        events.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def marker: Optional[String]
    def events: Optional[List[zio.aws.elasticache.model.Event.ReadOnly]]
    def getMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("marker", marker)
    def getEvents
        : ZIO[Any, AwsError, List[zio.aws.elasticache.model.Event.ReadOnly]] =
      AwsError.unwrapOptionField("events", events)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticache.model.DescribeEventsResponse
  ) extends zio.aws.elasticache.model.DescribeEventsResponse.ReadOnly {
    override val marker: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.marker())
      .map(value => value: String)
    override val events
        : Optional[List[zio.aws.elasticache.model.Event.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.events())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.elasticache.model.Event.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticache.model.DescribeEventsResponse
  ): zio.aws.elasticache.model.DescribeEventsResponse.ReadOnly = new Wrapper(
    impl
  )
}
